/*
 * opencvDepthRead.cpp
 * Retrieves the depth frame from the connected camera, and imports it into OpenCV for displaying.
 * Author: Cooper Lawrence, Metavues Tech
 * Last updated: 30/07/2019
 */

#include <MarsSDK.h>

#include <opencv2/core.hpp>
#include <opencv2/imgproc.hpp>
#include <opencv2/highgui.hpp>

#include <iostream>
#include <stdio.h>

int main()
{
	Mars* device = new Mars(); //Create a new Mars camera instance

	device->connect();

	DepthStream* depthStream = device->getDepthStream(); //Create the camera's depth stream

	//Create OpenCV Mat image to hold the depth image
	cv::Mat depth(depthStream->getHeight(), depthStream->getWidth(), CV_32FC3, depthStream->getFrame());
	cv::Mat axis[3];

	//Create OpenCV Mat image to hold the infrared image
	cv::Mat ir(depthStream->getHeight(), depthStream->getWidth(), CV_16U, depthStream->getIrFrame());

	//Load the depth frame buffer from the camera
	while (cv::waitKey(1) < 0)
	{
		//Update the depth stream and pseudo color
		depthStream->update();

		cv::split(depth, axis); //Split the depth frame into three axis (x, y, and z)

		cv::imshow("Depth", axis[2]); //Display the depth image
		cv::imshow("Infrared", ir); //Display the IR image
	}

	device->closeDepthStream();
	device->disconnect();

	return 0;
}
